@@ -190,13 +190,16 @@ def requirePackage(
                 "default": True,
             }
         ):
+            package_name = pname.split('.')[0] if not real_name else real_name
+            if not package_name: # 引用为自身
+                package_name = name
             with QproDefaultStatus(
-                f"Installing {pname if not real_name else real_name}"
+                f"Installing {package_name}"
                 if user_lang != "zh"
-                else f"正在安装 {pname if not real_name else real_name}"
+                else f"正在安装 {package_name}"
             ):
                 st, _ = external_exec(
-                    f"{set_pip} install {pname if not real_name else real_name} -U",
+                    f"{set_pip} install {package_name} -U",
                     True,
                 )
             if st:
@@ -205,7 +208,7 @@ def requirePackage(
                     f"Install {pname + (' -> ' + module if module else '')} failed, please install it manually: "
                     if user_lang != "zh"
                     else f"安装 {pname + (' -> ' + module if module else '')} 失败，请手动安装: ",
-                    f"'{set_pip} install {pname if not real_name else real_name} -U'",
+                    f"'{set_pip} install {package_name} -U'",
                 )
                 exit(-1)
             if not_exit:
